@@ -19,7 +19,10 @@
 
 static int	enable_c000 = FALSE;
 static int	enable_action = FALSE;
-static int	enable_basic = FALSE;
+
+extern int	rom_inserted;
+extern UBYTE	atari_basic[8192];
+extern UBYTE	atarixl_os[16384];
 
 UBYTE	*super;	/* For ACTION! supercart */
 
@@ -124,9 +127,6 @@ atari_main (int argc, char **argv)
 				case '9' :
 					countdown = 90000;
 					break;
-				case 'b' :
-					enable_basic = TRUE;
-					break;
 				case 'c' :
 					enable_c000 = TRUE;
 					break;
@@ -177,25 +177,80 @@ void Atari800_OS ()
 	unsigned short	devtab;
 
 	int	status;
+	int	i;
 /*
 	======================================================
 	Load Floating Point Package, Font and Operating System
 	======================================================
 */
-	status = load_image ("object/atariosb.rom", 65536-10240);
-	if (!status)
+	switch (machine)
 	{
-		printf ("Unable to load object/atariosb.rom\n");
-		exit (1);
+		case Atari :
+			status = load_image ("object/atariosb.rom", 0xd800);
+			if (!status)
+			{
+				printf ("Unable to load object/atariosb.rom\n");
+				exit (1);
+			}
+			break;
+		case AtariXL :
+		case AtariXE :
+			status = load_image ("object/atarixl.rom", 0xc000);
+			if (!status)
+			{
+				printf ("Unable to load object/atarixl.rom\n");
+				exit (1);
+			}
+			memcpy (atarixl_os, memory+0xc000, 0x4000);
+
+			status = load_image ("object/ataribas.rom", 0xa000);
+			if (!status)
+			{
+				printf ("Unable to load object/ataribas.rom\n");
+				exit (1);
+			}
+			memcpy (atari_basic, memory+0xa000, 0x2000);
+			break;
+		default :
+			printf ("Fatal Error in atari.c\n");
+			exit (1);
 	}
 
 	add_esc (0xe459, ESC_SIO);
+/*
+	=====================
+	Disable Checksum Test
+	=====================
+*/
+	switch (machine)
+	{
+		case Atari :
+			break;
+		case AtariXL :
+		case AtariXE :
+			memory[0xc314] = 0x8e;
+			memory[0xc315] = 0xff;
+			memory[0xc319] = 0x8e;
+			memory[0xc31a] = 0xff;
+			break;
+	}
 /*
 	==========================================
 	Patch O.S. - Modify Handler Table (HATABS)
 	==========================================
 */
-	for (addr=0xf0e3;addr<0xf0f2;addr+=3)
+	switch (machine)
+	{
+		case Atari :
+			addr = 0xf0e3;
+			break;
+		case AtariXL :
+		case AtariXE :
+			addr = 0xc42e;
+			break;
+	}
+
+	for (i=0;i<5;i++)
 	{
 		devtab = (GetByte(addr+2) << 8) | GetByte(addr+1);
 
@@ -280,20 +335,30 @@ void Atari800_OS ()
 			default :
 				break;
 		}
+
+		addr += 3;	/* Next Device in HATABS */
 	}
 /*
 	======================
 	Set O.S. Area into ROM
 	======================
 */
-	SetROM (0xd800, 0xffff);
-	SetHARDWARE (0xd000, 0xd7ff);
-
-	if (!enable_c000)
-		SetROM (0xc000, 0xcfff);
-
-	if (enable_basic && !rom_filename)
-		rom_filename = "object/ataribas.rom";
+	switch (machine)
+	{
+		case Atari :
+			SetROM (0xd800, 0xffff);
+			SetHARDWARE (0xd000, 0xd7ff);
+			if (enable_c000)
+				SetRAM (0xc000, 0xcfff);
+			else
+				SetROM (0xc000, 0xcfff);
+			break;
+		case AtariXL :
+		case AtariXE :
+			SetROM (0xc000, 0xffff);
+			SetHARDWARE (0xd000, 0xd7ff);
+			break;
+	}
 
 	if (rom_filename)
 	{
@@ -327,6 +392,12 @@ void Atari800_OS ()
 
 			SetROM (0xa000, 0xbfff);
 		}
+
+		rom_inserted = TRUE;
+	}
+	else
+	{
+		rom_inserted = FALSE;
 	}
 
 	Escape = Atari800_ESC;
@@ -349,7 +420,7 @@ int load_image (char *filename, int addr)
 	int	status = FALSE;
 	int	fd;
 
-	fd = open (filename, O_RDONLY);
+	fd = open (filename, O_RDONLY, 0777);
 	if (fd != -1)
 	{
 		char	ch;
