@@ -57,7 +57,9 @@ extern void  (*Escape)   (UBYTE code);
 #define	PutByte(addr,byte)	if (attrib[addr] == RAM) memory[addr] = byte; else if (attrib[addr] == HARDWARE) XPutByte(addr,byte);
 #define	GetWord(addr)		((GetByte(addr+1) << 8) | GetByte(addr))
 
-extern int	NMI;
-extern int	IRQ;
+#define	NMI_MASK	0x01
+#define	IRQ_MASK	0x02
+
+extern int	INTERRUPT;
 
 #endif
