@@ -14,13 +14,10 @@
 int	curses_mode;
 #endif
 
+Machine	machine = Atari;
+
 main (int argc, char **argv)
 {
-	enum
-	{
-		Atari
-	} machine = Atari;
-
 	int     i;
 	int	j;
 /*
@@ -36,6 +33,14 @@ main (int argc, char **argv)
 		{
 			machine = Atari;
 		}
+		else if (strcmp(argv[i], "-xl") == 0)
+		{
+			machine = AtariXL;
+		}
+		else if (strcmp(argv[i], "-xe") == 0)
+		{
+			machine = AtariXE;
+		}
 #ifdef CURSES
 		else if (strcmp(argv[i], "-left") == 0)
 			curses_mode = CURSES_LEFT;
@@ -54,13 +59,15 @@ main (int argc, char **argv)
 		}
 	}
 /*
-	===============================
-	Attach stderr to error.log file
-	===============================
+	============================================================
+	Attach stderr to error.log file except for SVGALIB and Amiga
+	===========================================================
 */
 #ifndef SVGALIB
+#ifndef AMIGA
 	freopen ("error.log", "w", stderr);
 #endif
+#endif
 /*
 	=========================
 	Invoke requested emulator
@@ -69,10 +76,12 @@ main (int argc, char **argv)
 	switch (machine)
 	{
 		case Atari :
+		case AtariXL :
+		case AtariXE :
 			atari_main (j, argv);
 			break;
 		default :
-			printf ("Usage: %s [-atari] [-help]\n");
+			printf ("Usage: %s [-atari] [-xl] [-xe] [-help]\n", argv[0]);
 			break;
 	}
 }
