@@ -7,12 +7,12 @@
 	=================================
 */
 
-typedef signed char		SBYTE;
-typedef signed short int	SWORD;
-typedef signed long int		SLONG;
-typedef unsigned char		UBYTE;
-typedef unsigned short int	UWORD;
-typedef unsigned long int	ULONG;
+#define	SBYTE	signed char
+#define	SWORD	signed short int
+#define	SLONG	signed long int
+#define	UBYTE	unsigned char
+#define	UWORD	unsigned short int
+#define	ULONG	unsigned long int
 
 #define	CURSES_LEFT	0x00
 #define	CURSES_CENTRAL	0x01
@@ -20,4 +20,13 @@ typedef unsigned long int	ULONG;
 #define	CURSES_WIDE_1	0x03
 #define	CURSES_WIDE_2	0x04
 
+typedef enum
+{
+	Atari,
+	AtariXL,
+	AtariXE
+} Machine;
+
+extern Machine	machine;
+
 #endif
